<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Preferences</name>
    <message>
        <source>Retas Level Format</source>
        <translation>RETAS Ebenen-Format</translation>
    </message>
    <message>
        <source>Adobe Photoshop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PNG</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No restrictions for uncompressed avi video</source>
        <translation>Keine Einschränkungen für unkompromiertes avi-Video</translation>
    </message>
    <message>
        <source>video width must be a multiple of %1</source>
        <translation>Video-Breite muss ein mehrfaches von %1 sein</translation>
    </message>
    <message>
        <source>video length must be a multiple of %1</source>
        <translation>Video-Länge muss ein mehrfaches von %1 sein</translation>
    </message>
    <message>
        <source>No restrictions for this codec</source>
        <translation>Keine Einschränkungen für diesen Codec</translation>
    </message>
    <message>
        <source>Resolution restrictions:</source>
        <translation>Beschränkungen für die Auflösung:</translation>
    </message>
    <message>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>Mit dem Codec kann nicht kommuniziert werden.
Wahrscheinlich funktioniert der Codec nicht korrekt.</translation>
    </message>
    <message>
        <source>%1-%2</source>
        <translation></translation>
    </message>
    <message>
        <source>%1</source>
        <translation></translation>
    </message>
    <message>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>Erwartete %1 Argument(e), %3 erhalten</translation>
    </message>
    <message>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1 ist keine gültige Farbe (gültige Farbeb sind &apos;rot&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, usw.)</translation>
    </message>
    <message>
        <source>Vectorization failed</source>
        <translation>Vektorisierung ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>Das Argument ist kein Datei-Pfad: %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>Inkorrektes Argument (%1): Es wird ein Bild benötigt</translation>
    </message>
    <message>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>Das Argument ist keine Frame-ID</translation>
    </message>
    <message>
        <source>First argument must be a scene : %1</source>
        <translation>Das erste Argument muss eine Szene sein: %1</translation>
    </message>
    <message>
        <source>Can&apos;t render empty scene</source>
        <translation>Kann keine leere Szene rendern</translation>
    </message>
    <message>
        <source>New Camera  %1</source>
        <translation>Neue Kamera  %1</translation>
    </message>
    <message>
        <source>New Pegbar  %1</source>
        <translation>Neue Haltestift-Leiste %1</translation>
    </message>
    <message>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>Aktive Kamera  %1 &gt; %2 setzen</translation>
    </message>
    <message>
        <source>Remove Spline  %1</source>
        <translation>Spline  %1 entfernen</translation>
    </message>
    <message>
        <source>New Motion Path  %1</source>
        <translation>Neuer Bewegungspfad  %1</translation>
    </message>
    <message>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>Bewegungspfad %1 &gt; %2 verbinden</translation>
    </message>
    <message>
        <source>Remove Object  %1</source>
        <translation>Object  %1 entfernen</translation>
    </message>
    <message>
        <source>Remove Column  </source>
        <translation>Spalte löschen</translation>
    </message>
    <message>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>In aktuelle Palette  &gt; %1 laden</translation>
    </message>
    <message>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>Durch aktuelle Palette  &gt; %1 ersetzen</translation>
    </message>
    <message>
        <source>Delete Studio Palette  : %1</source>
        <translation>Studio-Palette löschen  : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette  : %1</source>
        <translation>Studio-Palette erstellen  : %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>Ordner für Studio-Paletten löschen  : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>Ordner für Studio-Paletten erstellen  : %1</translation>
    </message>
    <message>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>Ordner für Studio-Paletten verschieben  : %1 : %2 &gt; %3</translation>
    </message>
    <message>
        <source>Arrange Styles  in Palette %1</source>
        <translation>Stile in Palette %1 umordnen</translation>
    </message>
    <message>
        <source>Create Style#%1  in Palette %2</source>
        <translation>Stil#%1 in Palette %2 erstellen</translation>
    </message>
    <message>
        <source>Add Style to Palette %1</source>
        <translation type="vanished">Stil zu Palette %1 hinzufügen</translation>
    </message>
    <message>
        <source>Add Page %1 to Palette %2</source>
        <translation>Seite %1 zu Palette %2 hinzufügen</translation>
    </message>
    <message>
        <source>Delete Page %1 from Palette %2</source>
        <translation>Seite %1 von Palette %2 entfernen</translation>
    </message>
    <message>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>Farbmodell %1 in Palette %2 laden</translation>
    </message>
    <message>
        <source>Move Page</source>
        <translation>Seite verschieben</translation>
    </message>
    <message>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>Seite %1 &gt; %2 umbenennen</translation>
    </message>
    <message>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>Stil#%1 in Palette %2 umbenennen: %3 &gt; %4</translation>
    </message>
    <message>
        <source>Add Fx  : </source>
        <translation>Effekt hinzufügen  : </translation>
    </message>
    <message>
        <source>Insert Fx  : </source>
        <translation>Effekt einfügen  : </translation>
    </message>
    <message>
        <source>Create Linked Fx  : %1</source>
        <translation>Verbundenen Effekt erstellen : %1</translation>
    </message>
    <message>
        <source>Replace Fx  : </source>
        <translation>Effekt ersetzen  : </translation>
    </message>
    <message>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>Verbundenen Effekt auflösen  : %1 - - %2</translation>
    </message>
    <message>
        <source>Make Macro Fx  : %1</source>
        <translation>Makro-Effekt erstellen  : %1</translation>
    </message>
    <message>
        <source>Explode Macro Fx  : %1</source>
        <translation>Makro-Effekt entfalten  : %1</translation>
    </message>
    <message>
        <source>Create Output Fx</source>
        <translation>Output-Effekt erstellen</translation>
    </message>
    <message>
        <source>Connect to Xsheet  : </source>
        <translation>Mit Xsheet verbinden  : </translation>
    </message>
    <message>
        <source>Disconnect from Xsheet  : </source>
        <translation>Verbindung mit Xsheet lösen : </translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Verbindung löschen</translation>
    </message>
    <message>
        <source>Delete Fx Node : %1</source>
        <translation>Effekt-Node löschen : %1</translation>
    </message>
    <message>
        <source>Paste Fx  :  </source>
        <translation>Effekt einfügen : </translation>
    </message>
    <message>
        <source>Disconnect Fx</source>
        <translation>Effekt trennen</translation>
    </message>
    <message>
        <source>Connect Fx : %1 - %2</source>
        <translation>Effekt verbinden : %1 - %2</translation>
    </message>
    <message>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>Effekt umbenennen: %1 &gt; %2</translation>
    </message>
    <message>
        <source>Group Fx</source>
        <translation>Effekt gruppieren</translation>
    </message>
    <message>
        <source>Ungroup Fx</source>
        <translation>Effekt-Gruppe auflösen</translation>
    </message>
    <message>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>Gruppe umbenennen : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Set Keyframe</source>
        <translation>Keyframe setzen</translation>
    </message>
    <message>
        <source>Remove Keyframe</source>
        <translation>Keyframe löschen</translation>
    </message>
    <message>
        <source>Cycle</source>
        <translation>Durchschalten</translation>
    </message>
    <message>
        <source>The autocentering failed on the current drawing.</source>
        <translation>Das automatische Zentrieren ist bei der aktuellen Zeichnung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Verschieben</translation>
    </message>
    <message>
        <source>Edit Rotation</source>
        <translation>Rotation bearbeiten</translation>
    </message>
    <message>
        <source>Move X</source>
        <translation>X verschieben</translation>
    </message>
    <message>
        <source>Move Y</source>
        <translation>Y verschieben</translation>
    </message>
    <message>
        <source>Move Z</source>
        <translation>Z verschieben</translation>
    </message>
    <message>
        <source>Edit Stack Order</source>
        <translation>Stapel-Reihenfolge bearbeiten</translation>
    </message>
    <message>
        <source>Edit Scale W</source>
        <translation>Breite skalieren</translation>
    </message>
    <message>
        <source>Edit Scale H</source>
        <translation>Höhe skalieren</translation>
    </message>
    <message>
        <source>Edit Scale</source>
        <translation>Größe bearbeiten</translation>
    </message>
    <message>
        <source>Edit PosPath</source>
        <translation>Pos-Pfad bearbeiten</translation>
    </message>
    <message>
        <source>Edit Shear X</source>
        <translation>X-Scherung bearbeiten</translation>
    </message>
    <message>
        <source>Edit Shear Y</source>
        <translation>Y-Scherung bearbeiten</translation>
    </message>
    <message>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  Frame : %3</translation>
    </message>
    <message>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>Keyframe %1 bei Frame %2 setzen</translation>
    </message>
    <message>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>Keyframe %1 bei Frame %2 entfernen</translation>
    </message>
    <message>
        <source>Move Center   %1  Frame %2</source>
        <translation>Verschiebe Zentrum %1 Frame %2</translation>
    </message>
    <message>
        <source>Add Style  to Palette %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>color model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DarkYellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DarkCyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DarkMagenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HRange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ColorThres</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WhiteThres</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t undo rename palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t undo move palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t redo rename palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t redo move palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save the following resources:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and %1 more item(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Purple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark Pink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Kann Ebene %1 nicht vektorisieren</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Kann keine Ebene ohne Frames vektorisieren</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Kann Bild %1 nicht vektorisieren</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Inkorrektes Argument (%1): Es sollte ein Bild oder eine Ebene sein</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation>&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>kann keinen absoluten Pfad verketten : %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation>%1 ist kein gültiges Verzeichnis</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation>kann Verzeichnis %1 nicht lesen</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Datei %1 existiert nicht</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation>Erster Frame von %1 wurde geladen</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation>Unerwarteter Fehler beim Laden des Bildes</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>Unbekannter Dateityp :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>Kann kein %1 Bild zu diesem Dateityp speichen : %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation>Unerwarteter Fehler beim Speichern des Bildes</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>Inkorrektes Argument (%1): Es sollte ein Raster oder ToonzRaster sein</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation>ImageBuilder(%1 Bild)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>Inkorrektes Argument (%1): Es sollte eine Transformierung sein</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <source>%1 frames</source>
        <translation>%1 Frames</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>Inkorrektes Argument (%1): Es sollte ein Datei-Pfad oder String sein</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation>Ausnahme beim Laden von Ebene (%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Datei %1 existiert nicht</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation>Datei %1 wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>Ausnahme beim Lesen von %1</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation>Kann keine leere Ebene speichern</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>Unbekannter Dateityp :</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>Kann keine %1 Ebene zu diesem Dateityp speichen : %2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>Ausnahme beim Schreiben von %1</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation>Frame-Index (%1) muss eine Nummer sein</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>Frame-Index (%1) ist außerhalb des Bereichs (0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation>zweites Argument (%1) ist kein Bild</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation>kann kein %1 Bild in eine Ebene einfügen</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>kann kein %1 Bild in eine %2 Ebene einfügen</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>Kann keine %1 Ebene vektorisieren</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>Kann keine Ebene ohne Frames vektorisieren</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>Kann kein %1 Bild vektorisieren</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>Inkorrektes Argument (%1): Es sollte ein Bild oder eine Ebene sein</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation>Ungültige Farbe : </translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation>Es ist kein Vektor-Bild: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation>Es ist keine Vektor-Ebene: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation>Argument muss eine Vektor-Ebene oder Bild sein : </translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation>%1 hat keine Palette</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>Datei %1 existiert nicht</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>Ausnahme beim Lesen von %1</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>Ausnahme beim Schreiben von %1</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>Inkorrekter Ebenentyp (%1): Es muss vom Typ Vektor, Raster oder ToonzRaster sein</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>Kann die Ebene nicht hinzufügen: Der Name (%1) wird bereits verwendet</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>Kann diesen Dateityp nicht als Ebene laden : %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation>Konnte Ebene %1 nicht laden</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation>Ebene ist nicht in der Szene vorhanden: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1 : Ist weder eine Ebenen-Instanz noch ein Ebenen-Namen</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>Ebene &apos;%1&apos; ist nicht in der Szene vorhanden</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation>Kann keine %1 Ebene umwandeln</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>Kann keine Ebene ohne Frames umwandeln</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation>Kann kein %1 Bild umwandeln</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>Inkorrektes Argument (%1): Es muss eine Raster-Ebene oder eine Raster-Bild sein</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <source>Identity</source>
        <translation>Identitätsmatrix</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation>Verschiebung(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation>Rotation(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation>Skalierung(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation>Skalierung(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>Transformierung(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
